import React from 'react'
import { Area, XAxis, YAxis, Tooltip, ResponsiveContainer, Legend, Line, ComposedChart } from 'recharts';
import { MultiAreaChartProps } from './MultiAreaChart.types';

const MultiAreaChart = ({ data, legend, tooltip = { trigger: "hover" } }: MultiAreaChartProps) => {
  const mapData = () => {
    let mappedData: any = []
    for (let i = 0; i < data.xAxis.values.length; i++) {
      let dataObj: any = {
        name: data.xAxis.values[i]
      }
      data.areas.forEach((a: any) => dataObj[a.key] = a.values[i])
      data.lines.forEach((l: any) => dataObj[l.key] = l.values[i])
      mappedData.push(dataObj)
    }
    return mappedData
  }

  return (
    <>
      <ResponsiveContainer height="90%">
        <ComposedChart data={mapData()}>
          <XAxis dataKey="name" />
          <YAxis />
          {tooltip.customTooltip !== undefined ?
           <Tooltip trigger={tooltip.trigger} content={tooltip.customTooltip} /> 
           :
           <Tooltip trigger={tooltip.trigger} /> 
          }
          {legend.show && <Legend verticalAlign="top" height={36} />}
          {data.areas.map((a: any, i: number) => <Area key={"a"+i} type="monotone" name={a.label} stackId={a.stackIndex} dataKey={a.key} fill={a.fill} stroke={a.stroke} opacity={a.opacity} dot />)}
          {data.lines.map((l: any, i: number) => <Line key={"l"+i} type="monotone" name={l.label} dataKey={l.key} stroke={l.stroke} opacity={l.opacity} strokeWidth={l.width} />)}
        </ComposedChart>
      </ResponsiveContainer>
    </>
  )
}


export default MultiAreaChart